@@ -78,6 +78,9 @@ int main(int argc, char **argv)
     sAgentManager = new AgentManager;
     AkonadiCrash::setEmergencyMethod(crashHandler);
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+    QGuiApplication::setFallbackSessionManagementEnabled(false);
+#endif
     // akonadi_control is started on-demand, no need to auto restart by session.
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
