@@ -89,6 +89,23 @@ CollectionAttribute::List List::getAttributes(const Collection &col, const QSet<
         }
         ++it;
     }
+
+    // We need the reference and enabled status, to not need to request the server mutliple times.
+    // Mostly interessting for ancestors for i.e. updates provided by the monitor.
+    const bool isReferenced = connection()->collectionReferenceManager()->isReferenced(col.id(), connection()->sessionId());
+    if (isReferenced) {
+        CollectionAttribute attr;
+        attr.setType(AKONADI_PARAM_REFERENCED);
+        attr.setValue("TRUE");
+        attributes << attr;
+    }
+    {
+        CollectionAttribute attr;
+        attr.setType(AKONADI_PARAM_ENABLED);
+        attr.setValue(col.enabled() ? "TRUE" : "FALSE");
+        attributes << attr;
+    }
+
     return attributes;
 }
 
@@ -102,7 +119,7 @@ void List::listCollection(const Collection &root, const QStack<Collection> &ance
     const bool resourceIsSynchronizing = root.referenced() && mCollectionsToSynchronize && connection()->context()->resource().isValid();
 
     QStack<CollectionAttribute::List> ancestorAttributes;
-    //backwards compatibilty, collectionToByteArray will automatically fall-back to id + remoteid
+    //backwards compatibility, collectionToByteArray will automatically fall-back to id + remoteid
     if (!mAncestorAttributes.isEmpty()) {
         ancestorAttributes.reserve(ancestors.size());
         Q_FOREACH (const Collection &col, ancestors) {
@@ -326,7 +343,7 @@ void List::retrieveCollections(const Collection &topParent, int depth)
                 }
             }
 
-            //If we matched referenced collecions we need to ensure the collection was referenced from this session
+            //If we matched referenced collections we need to ensure the collection was referenced from this session
             const bool isReferencedFromSession = connection()->collectionReferenceManager()->isReferenced(it->id(), connection()->sessionId());
             //The collection is referenced, but not from this session. We need to reevaluate the filter condition
             if (it->referenced() && !isReferencedFromSession) {
