@@ -20,7 +20,6 @@
 
 #include "searchmanager.h"
 #include "abstractsearchplugin.h"
-#include "searchmanageradaptor.h"
 #include "akonadiserver_debug.h"
 
 #include "agentsearchengine.h"
@@ -57,23 +56,106 @@ Q_DECLARE_METATYPE(Collection)
 Q_DECLARE_METATYPE(QSet<qint64>)
 Q_DECLARE_METATYPE(QSemaphore *)
 
-SearchManagerThread::SearchManagerThread(const QStringList &searchEngines, QObject *parent)
-    : QThread(parent)
-    , mSearchEngines(searchEngines)
+SearchManager::SearchManager(const QStringList &searchEngines, QObject *parent)
+    : AkThread(AkThread::ManualStart, QThread::InheritPriority, parent)
+    , mEngineNames(searchEngines)
 {
-    Q_ASSERT(QThread::currentThread() == QCoreApplication::instance()->thread());
+    setObjectName(QStringLiteral("SearchManager"));
+
+    qRegisterMetaType<QSet<qint64>>();
+    qRegisterMetaType<Collection>();
+    qRegisterMetaType<QSemaphore *>();
+
+    Q_ASSERT(sInstance == 0);
+    sInstance = this;
 
     // We load search plugins (as in QLibrary::load()) in the main thread so that
     // static initialization happens in the QApplication thread
     loadSearchPlugins();
+
+    // Register to DBus on the main thread connection - otherwise we don't appear
+    // on the service.
+    QDBusConnection conn = QDBusConnection::sessionBus();
+    conn.registerObject(QStringLiteral("/SearchManager"), this,
+                        QDBusConnection::ExportAllSlots);
+
+    // Delay-call init()
+    startThread();
 }
 
-SearchManagerThread::~SearchManagerThread()
+void SearchManager::init()
 {
-    qDeleteAll(mPluginLoaders);
+    AkThread::init();
+
+    mEngines.reserve(mEngineNames.size());
+    Q_FOREACH (const QString &engineName, mEngineNames) {
+        if (engineName == QLatin1String("Agent")) {
+            mEngines.append(new AgentSearchEngine);
+        } else {
+            akError() << "Unknown search engine type: " << engineName;
+        }
+    }
+
+    initSearchPlugins();
+
+    // The timer will tick 15 seconds after last change notification. If a new notification
+    // is delivered in the meantime, the timer is reset
+    mSearchUpdateTimer = new QTimer(this);
+    mSearchUpdateTimer->setInterval(15 * 1000);
+    mSearchUpdateTimer->setSingleShot(true);
+    connect(mSearchUpdateTimer, &QTimer::timeout,
+            this, &SearchManager::searchUpdateTimeout);
 }
 
-void SearchManagerThread::loadSearchPlugins()
+void SearchManager::quit()
+{
+    QDBusConnection conn = DBusConnectionPool::threadConnection();
+    conn.unregisterObject(QStringLiteral("/SearchManager"), QDBusConnection::UnregisterTree);
+    conn.disconnectFromBus(conn.name());
+
+    // Make sure all childrens are deleted within context of this thread
+    qDeleteAll(children());
+
+    qDeleteAll(mEngines);
+    qDeleteAll(mPlugins);
+    Q_FOREACH (QPluginLoader *loader, mPluginLoaders) {
+        loader->unload();
+        delete loader;
+    }
+
+    AkThread::quit();
+}
+
+
+SearchManager::~SearchManager()
+{
+    quitThread();
+
+    sInstance = 0;
+}
+
+SearchManager *SearchManager::instance()
+{
+    Q_ASSERT(sInstance);
+    return sInstance;
+}
+
+void SearchManager::registerInstance(const QString &id)
+{
+    SearchTaskManager::instance()->registerInstance(id);
+}
+
+void SearchManager::unregisterInstance(const QString &id)
+{
+    SearchTaskManager::instance()->unregisterInstance(id);
+}
+
+QVector<AbstractSearchPlugin *> SearchManager::searchPlugins() const
+{
+    return mPlugins;
+}
+
+void SearchManager::loadSearchPlugins()
 {
     QStringList loadedPlugins;
     const QString pluginOverride = QString::fromLatin1(qgetenv("AKONADI_OVERRIDE_SEARCHPLUGIN"));
@@ -90,8 +172,8 @@ void SearchManagerThread::loadSearchPlugins()
             const QString filePath = pluginDir % QLatin1String("/akonadi/") % fileName;
             std::unique_ptr<QPluginLoader> loader(new QPluginLoader(filePath));
             const QVariantMap metadata = loader->metaData().value(QStringLiteral("MetaData")).toVariant().toMap();
-
             if (metadata.value(QStringLiteral("X-Akonadi-PluginType")).toString() != QLatin1String("SearchPlugin")) {
+                akDebug() << "===>" << fileName << metadata.value(QStringLiteral("X-Akonadi-PluginType")).toString();
                 continue;
             }
 
@@ -124,87 +206,9 @@ void SearchManagerThread::loadSearchPlugins()
     }
 }
 
-
-void SearchManagerThread::run()
+void SearchManager::initSearchPlugins()
 {
-    SearchManager *manager = new SearchManager();
-    manager->init(mSearchEngines, mPluginLoaders);
-    exec();
-    delete manager;
-}
-
-SearchManager::SearchManager(QObject *parent)
-    : QObject(parent)
-{
-    qRegisterMetaType< QSet<qint64> >();
-    qRegisterMetaType<Collection>();
-    qRegisterMetaType<QSemaphore *>();
-
-    Q_ASSERT(sInstance == 0);
-    sInstance = this;
-
-    DataStore::self();
-}
-
-void SearchManager::init(const QStringList &searchEngines, const QList<QPluginLoader*> &loaders)
-{
-    mEngines.reserve(searchEngines.size());
-    Q_FOREACH (const QString &engineName, searchEngines) {
-        if (engineName == QLatin1String("Agent")) {
-            mEngines.append(new AgentSearchEngine);
-        } else {
-            akError() << "Unknown search engine type: " << engineName;
-        }
-    }
-
-    initSearchPlugins(loaders);
-
-    new SearchManagerAdaptor(this);
-    QDBusConnection::sessionBus().registerObject(
-        QStringLiteral("/SearchManager"),
-        this,
-        QDBusConnection::ExportAdaptors);
-
-    // The timer will tick 15 seconds after last change notification. If a new notification
-    // is delivered in the meantime, the timer is reset
-    mSearchUpdateTimer = new QTimer(this);
-    mSearchUpdateTimer->setInterval(15 * 1000);
-    mSearchUpdateTimer->setSingleShot(true);
-    connect(mSearchUpdateTimer, &QTimer::timeout,
-            this, &SearchManager::searchUpdateTimeout);
-}
-
-SearchManager::~SearchManager()
-{
-    qDeleteAll(mEngines);
-    DataStore::self()->close();
-    sInstance = 0;
-}
-
-SearchManager *SearchManager::instance()
-{
-    Q_ASSERT(sInstance);
-    return sInstance;
-}
-
-void SearchManager::registerInstance(const QString &id)
-{
-    SearchTaskManager::instance()->registerInstance(id);
-}
-
-void SearchManager::unregisterInstance(const QString &id)
-{
-    SearchTaskManager::instance()->unregisterInstance(id);
-}
-
-QVector<AbstractSearchPlugin *> SearchManager::searchPlugins() const
-{
-    return mPlugins;
-}
-
-void SearchManager::initSearchPlugins(const QList<QPluginLoader*> &loaders)
-{
-    for (QPluginLoader *loader : loaders) {
+    for (QPluginLoader *loader : mPluginLoaders) {
         if (!loader->load()) {
             akError() << "Failed to load search plugin" << loader->fileName() << ":" << loader->errorString();
             continue;
