@@ -30,6 +30,7 @@
 
 #include <QtCore/QDir>
 #include <QtCore/QStringBuilder>
+#include <QProcess>
 
 using namespace Akonadi;
 using namespace Akonadi::Server;
@@ -136,3 +137,9 @@ void DbConfig::initSession(const QSqlDatabase &database)
 {
     Q_UNUSED(database);
 }
+
+int DbConfig::execute(const QString &cmd, const QStringList &args) const
+{
+    akDebug() << "Executing: " << cmd << args.join(QLatin1Char(' '));
+    return QProcess::execute(cmd, args);
+}
