@@ -29,6 +29,7 @@
 #include <QtCore/QDir>
 #include <QtCore/QProcess>
 #include <QtCore/QThread>
+#include <QRegularExpression>
 #include <QtSql/QSqlDriver>
 #include <QtSql/QSqlError>
 #include <QtSql/QSqlQuery>
@@ -39,6 +40,8 @@ using namespace Akonadi::Server;
 #define MYSQL_MIN_MAJOR 5
 #define MYSQL_MIN_MINOR 1
 
+#define MYSQL_VERSION_CHECK(major, minor, patch) ((major << 16) | (minor << 8) | patch)
+
 DbConfigMysql::DbConfigMysql()
     : mInternalServer(true)
     , mDatabaseProcess(0)
@@ -115,7 +118,7 @@ bool DbConfigMysql::init(QSettings &settings)
     mUserName = settings.value(QStringLiteral("User")).toString();
     mPassword = settings.value(QStringLiteral("Password")).toString();
     mConnectionOptions = settings.value(QStringLiteral("Options"), defaultOptions).toString();
-    mServerPath = settings.value(QStringLiteral("ServerPath"), defaultServerPath).toString();
+    mMysqldPath = settings.value(QStringLiteral("ServerPath"), defaultServerPath).toString();
     mCleanServerShutdownCommand = settings.value(QStringLiteral("CleanServerShutdownCommand"), defaultCleanShutdownCommand).toString();
     settings.endGroup();
 
@@ -125,17 +128,19 @@ bool DbConfigMysql::init(QSettings &settings)
         // intentionally not namespaced as we are the only one in this db instance when using internal mode
         mDatabaseName = QStringLiteral("akonadi");
     }
-    if (mInternalServer && (mServerPath.isEmpty() || !QFile::exists(mServerPath))) {
-        mServerPath = defaultServerPath;
+    if (mInternalServer && (mMysqldPath.isEmpty() || !QFile::exists(mMysqldPath))) {
+        mMysqldPath = defaultServerPath;
     }
 
+    akDebug() << "Using mysqld:" << mMysqldPath;
+
     // store back the default values
     settings.beginGroup(driverName());
     settings.setValue(QStringLiteral("Name"), mDatabaseName);
     settings.setValue(QStringLiteral("Host"), mHostName);
     settings.setValue(QStringLiteral("Options"), mConnectionOptions);
-    if (!mServerPath.isEmpty()) {
-        settings.setValue(QStringLiteral("ServerPath"), mServerPath);
+    if (!mMysqldPath.isEmpty()) {
+        settings.setValue(QStringLiteral("ServerPath"), mMysqldPath);
     }
     settings.setValue(QStringLiteral("StartServer"), mInternalServer);
     settings.endGroup();
@@ -180,7 +185,6 @@ bool DbConfigMysql::useInternalServer() const
 bool DbConfigMysql::startInternalServer()
 {
     bool success = true;
-    const QString mysqldPath = mServerPath;
 
     const QString akDir   = StandardDirs::saveDir("data");
     const QString dataDir = StandardDirs::saveDir("data", QStringLiteral("db_data"));
@@ -209,6 +213,26 @@ bool DbConfigMysql::startInternalServer()
     }
 #endif
 
+    if (mMysqldPath.isEmpty()) {
+        akError() << "mysqld not found. Please verify your installation";
+        return false;
+    }
+
+    // Get the version of the mysqld server that we'll be using.
+    // MySQL (but not MariaDB) deprecates and removes command line options in
+    // patch version releases, so we need to adjust the command line options accordingly
+    // when running the helper utilities or starting the server
+    const unsigned int localVersion = parseCommandLineToolsVersion();
+    if (localVersion == 0x000000) {
+        akError() << "Failed to detect mysqld version!";
+    }
+    // TODO: Parse "MariaDB" or "MySQL" from the version string instead of relying
+    // on the version numbers
+    const bool isMariaDB = localVersion >= MYSQL_VERSION_CHECK(10, 0, 0);
+    akDebug().nospace() << "mysqld reports version " << (localVersion >> 16) << "." << ((localVersion >> 8) & 0x0000FF) << "." << (localVersion & 0x0000FF)
+                        << " (" << (isMariaDB ? "MariaDB" : "Oracle MySQL") << ")";
+
+
     bool confUpdate = false;
     QFile actualFile(actualConfig);
     // update conf only if either global (or local) is newer than actual
@@ -285,8 +309,13 @@ bool DbConfigMysql::startInternalServer()
     // first run, some MySQL versions need a mysql_install_db run for that
     const QString confFile = XdgBaseDirs::findResourceFile("config", QStringLiteral("akonadi/mysql-global.conf"));
     if (QDir(dataDir).entryList(QDir::NoDotAndDotDot | QDir::AllEntries).isEmpty() && !mMysqlInstallDbPath.isEmpty()) {
-        const QStringList arguments = QStringList() << QStringLiteral("--force") << QStringLiteral("--defaults-file=%1").arg(confFile) << QStringLiteral("--datadir=%1/").arg(dataDir);
-        QProcess::execute(mMysqlInstallDbPath, arguments);
+        if (isMariaDB) {
+            initializeMariaDBDatabase(confFile, dataDir);
+        } else if (localVersion >= MYSQL_VERSION_CHECK(5, 7, 6)) {
+            initializeMySQL5_7_6Database(confFile, dataDir);
+        } else {
+            initializeMySQLDatabase(confFile, dataDir);
+        }
     }
 
     // clear mysql ib_logfile's in case innodb_log_file_size option changed in last confUpdate
@@ -305,15 +334,12 @@ bool DbConfigMysql::startInternalServer()
     arguments << QString::fromLatin1("--shared-memory");
 #endif
 
-    if (mysqldPath.isEmpty()) {
-        akError() << "mysqld not found. Please verify your installation";
-        return false;
-    }
+    akDebug() << "Executing:" << mMysqldPath << arguments.join(QLatin1Char(' '));
     mDatabaseProcess = new QProcess;
-    mDatabaseProcess->start(mysqldPath, arguments);
+    mDatabaseProcess->start(mMysqldPath, arguments);
     if (!mDatabaseProcess->waitForStarted()) {
         akError() << "Could not start database server!";
-        akError() << "executable:" << mysqldPath;
+        akError() << "executable:" << mMysqldPath;
         akError() << "arguments:" << arguments;
         akError() << "process error:" << mDatabaseProcess->errorString();
         return false;
@@ -347,7 +373,7 @@ bool DbConfigMysql::startInternalServer()
             }
             if (mDatabaseProcess->waitForFinished(500)) {
                 akError() << "Database process exited unexpectedly during initial connection!";
-                akError() << "executable:" << mysqldPath;
+                akError() << "executable:" << mMysqldPath;
                 akError() << "arguments:" << arguments;
                 akError() << "stdout:" << mDatabaseProcess->readAllStandardOutput();
                 akError() << "stderr:" << mDatabaseProcess->readAllStandardError();
@@ -359,15 +385,14 @@ bool DbConfigMysql::startInternalServer()
 
         if (opened) {
             if (!mMysqlCheckPath.isEmpty()) {
-                const QStringList arguments = QStringList() << QStringLiteral("--defaults-file=%1/mysql.conf").arg(akDir)
-                                              << QStringLiteral("--check-upgrade")
-                                              << QStringLiteral("--all-databases")
-                                              << QStringLiteral("--auto-repair")
+                execute(mMysqlCheckPath, { QStringLiteral("--defaults-file=%1/mysql.conf").arg(akDir),
+                                           QStringLiteral("--check-upgrade"),
+                                           QStringLiteral("--auto-repair"),
 #ifndef Q_OS_WIN
-                                              << QStringLiteral("--socket=%1/mysql.socket").arg(socketDirectory)
+                                           QStringLiteral("--socket=%1/mysql.socket").arg(socketDirectory),
 #endif
-                                              ;
-                QProcess::execute(mMysqlCheckPath, arguments);
+                                           mDatabaseName
+                                         });
             }
 
             // Verify MySQL version
@@ -454,3 +479,47 @@ void DbConfigMysql::initSession(const QSqlDatabase &database)
     QSqlQuery query(database);
     query.exec(QStringLiteral("SET SESSION TRANSACTION ISOLATION LEVEL READ COMMITTED"));
 }
+
+int DbConfigMysql::parseCommandLineToolsVersion() const
+{
+    QProcess mysqldProcess;
+    mysqldProcess.start(mMysqldPath, { QStringLiteral("--version") });
+    mysqldProcess.waitForFinished(10000 /* 10 secs */);
+
+    const QString out = QString::fromLocal8Bit(mysqldProcess.readAllStandardOutput());
+    QRegularExpression regexp(QStringLiteral("Ver ([0-9]+)\\.([0-9]+)\\.([0-9]+)"));
+    auto match = regexp.match(out);
+    if (!match.hasMatch()) {
+        return 0;
+    }
+
+    return (match.capturedRef(1).toInt() << 16) | (match.capturedRef(2).toInt() << 8) | match.capturedRef(3).toInt();
+}
+
+bool DbConfigMysql::initializeMariaDBDatabase(const QString &confFile, const QString &dataDir) const
+{
+    return 0 == execute(mMysqlInstallDbPath,
+                        { QStringLiteral("--defaults-file=%1").arg(confFile),
+                          QStringLiteral("--force"),
+                          QStringLiteral("--datadir=%1/").arg(dataDir) });
+}
+
+/**
+ * As of MySQL 5.7.6 mysql_install_db is deprecated and mysqld --initailize should be used instead
+ * See MySQL Reference Manual section 2.10.1.1 (Initializing the Data Directory Manually Using mysqld)
+ */
+bool DbConfigMysql::initializeMySQL5_7_6Database(const QString &confFile, const QString &dataDir) const
+{
+    return 0 == execute(mMysqldPath,
+                        { QStringLiteral("--defaults-file=%1").arg(confFile),
+                          QStringLiteral("--initialize"),
+                          QStringLiteral("--datadir=%1/").arg(dataDir) });
+}
+
+bool DbConfigMysql::initializeMySQLDatabase(const QString &confFile, const QString &dataDir) const
+{
+    // Don't use --force, it has been removed in MySQL 5.7.5
+    return 0 == execute(mMysqlInstallDbPath,
+                        {  QStringLiteral("--defaults-file=%1").arg(confFile),
+                           QStringLiteral("--datadir=%1/").arg(dataDir) });
+}
