@@ -47,10 +47,6 @@ ItemRetriever::ItemRetriever(Connection *connection)
 {
 }
 
-ItemRetriever::~ItemRetriever()
-{
-}
-
 Connection *ItemRetriever::connection() const
 {
     return mConnection;
@@ -132,24 +128,21 @@ enum QueryColumns {
     PimItemIdColumn,
     PimItemRidColumn,
 
-    MimeTypeColumn,
+    MimeTypeIdColumn,
 
-    ResourceColumn,
+    ResourceIdColumn,
 
     PartTypeNameColumn,
     PartDatasizeColumn
 };
 
+
 QSqlQuery ItemRetriever::buildQuery() const
 {
     QueryBuilder qb(PimItem::tableName());
 
-    qb.addJoin(QueryBuilder::InnerJoin, MimeType::tableName(), PimItem::mimeTypeIdFullColumnName(), MimeType::idFullColumnName());
-
     qb.addJoin(QueryBuilder::InnerJoin, Collection::tableName(), PimItem::collectionIdFullColumnName(), Collection::idFullColumnName());
 
-    qb.addJoin(QueryBuilder::InnerJoin, Resource::tableName(), Collection::resourceIdFullColumnName(), Resource::idFullColumnName());
-
     qb.addJoin(QueryBuilder::LeftJoin, Part::tableName(), PimItem::idFullColumnName(), Part::pimItemIdFullColumnName());
 
     Query::Condition partTypeJoinCondition;
@@ -157,13 +150,13 @@ QSqlQuery ItemRetriever::buildQuery() const
     if (!mFullPayload && !mParts.isEmpty()) {
         partTypeJoinCondition.addCondition(PartTypeHelper::conditionFromFqNames(mParts));
     }
-    partTypeJoinCondition.addValueCondition(PartType::nsFullColumnName(), Query::Equals, QLatin1String("PLD"));
+    partTypeJoinCondition.addValueCondition(PartType::nsFullColumnName(), Query::Equals, QStringLiteral("PLD"));
     qb.addJoin(QueryBuilder::LeftJoin, PartType::tableName(), partTypeJoinCondition);
 
     qb.addColumn(PimItem::idFullColumnName());
     qb.addColumn(PimItem::remoteIdFullColumnName());
-    qb.addColumn(MimeType::nameFullColumnName());
-    qb.addColumn(Resource::nameFullColumnName());
+    qb.addColumn(PimItem::mimeTypeIdFullColumnName());
+    qb.addColumn(Collection::resourceIdFullColumnName());
     qb.addColumn(PartType::nameFullColumnName());
     qb.addColumn(Part::datasizeFullColumnName());
 
@@ -175,8 +168,10 @@ QSqlQuery ItemRetriever::buildQuery() const
 
     // prevent a resource to trigger item retrieval from itself
     if (mConnection) {
-        qb.addValueCondition(Resource::nameFullColumnName(), Query::NotEquals,
-                             QString::fromLatin1(mConnection->sessionId()));
+        const Resource res = Resource::retrieveByName(QString::fromUtf8(mConnection->sessionId()));
+        if (res.isValid()) {
+            qb.addValueCondition(Collection::resourceIdFullColumnName(), Query::NotEquals, res.id());
+        }
     }
 
     if (mChangedSince.isValid()) {
@@ -208,21 +203,33 @@ bool ItemRetriever::exec()
     ItemRetrievalRequest *lastRequest = 0;
     QList<ItemRetrievalRequest *> requests;
 
-    QVector<QByteArray> parts;
+    QByteArrayList parts;
     Q_FOREACH (const QByteArray &part, mParts) {
         if (part.startsWith(AKONADI_PARAM_PLD)) {
             parts << part.mid(4);
         }
     }
 
+    QHash<qint64, QString> mimeTypeIdNameCache;
+    QHash<qint64, QString> resourceIdNameCache;
     while (query.isValid()) {
         const qint64 pimItemId = query.value(PimItemIdColumn).toLongLong();
         if (!lastRequest || lastRequest->id != pimItemId) {
             lastRequest = new ItemRetrievalRequest();
             lastRequest->id = pimItemId;
-            lastRequest->remoteId = Utils::variantToByteArray(query.value(PimItemRidColumn));
-            lastRequest->mimeType = Utils::variantToByteArray(query.value(MimeTypeColumn));
-            lastRequest->resourceId = Utils::variantToString(query.value(ResourceColumn));
+            lastRequest->remoteId = Utils::variantToString(query.value(PimItemRidColumn));
+            const qint64 mtId = query.value(MimeTypeIdColumn).toLongLong();
+            auto mtIter = mimeTypeIdNameCache.find(mtId);
+            if (mtIter == mimeTypeIdNameCache.end()) {
+                mtIter = mimeTypeIdNameCache.insert(mtId, MimeType::retrieveById(mtId).name());
+            }
+            lastRequest->mimeType = *mtIter;
+            const qint64 resourceId = query.value(ResourceIdColumn).toLongLong();
+            auto resIter = resourceIdNameCache.find(resourceId);
+            if (resIter == resourceIdNameCache.end()) {
+                resIter = resourceIdNameCache.insert(resourceId, Resource::retrieveById(resourceId).name());
+            }
+            lastRequest->resourceId = *resIter;
             lastRequest->parts = parts;
             requests << lastRequest;
         }
