@@ -20,7 +20,7 @@
 #ifndef STORAGEJANITOR_H
 #define STORAGEJANITOR_H
 
-#include <QThread>
+#include "akthread.h"
 
 #include <QtDBus/QDBusConnection>
 
@@ -29,19 +29,10 @@ namespace Server {
 
 class Collection;
 
-class StorageJanitorThread : public QThread
-{
-    Q_OBJECT
-public:
-    explicit StorageJanitorThread(QObject *parent = 0);
-protected:
-    void run();
-};
-
 /**
  * Various database checking/maintenance features.
  */
-class StorageJanitor : public QObject
+class StorageJanitor : public AkThread
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Akonadi.Janitor")
@@ -61,6 +52,10 @@ Q_SIGNALS:
     Q_SCRIPTABLE void information(const QString &msg);
     Q_SCRIPTABLE void done();
 
+protected:
+    void init() Q_DECL_OVERRIDE;
+    void quit() Q_DECL_OVERRIDE;
+
 private:
     void inform(const char *msg);
     void inform(const QString &msg);
@@ -113,6 +108,13 @@ private:
      */
     void findDirtyObjects();
 
+    /**
+     * Look for duplicates by RID.
+     *
+     * ..and remove the one that doesn't match the parent collections content mimetype.
+     */
+    void findRIDDuplicates();
+
     /**
      * Check whether part sizes match what's in database.
      *
@@ -128,7 +130,6 @@ private:
     void migrateToLevelledCacheHierarchy();
 
 private:
-    QDBusConnection m_connection;
     qint64 m_lostFoundCollectionId;
 };
 
