@@ -23,10 +23,8 @@
 
 #include "akdebug.h"
 #include "akcrash.h"
-#include "akstandarddirs.h"
 
-#include <private/xdgbasedirs_p.h>
-using Akonadi::XdgBaseDirs;
+#include <private/standarddirs_p.h>
 
 #include <QDir>
 #include <QFile>
@@ -103,10 +101,10 @@ public:
 
     QString errorLogFileName() const
     {
-        return AkStandardDirs::saveDir("data")
+        return Akonadi::StandardDirs::saveDir("data")
                + QDir::separator()
                + name
-               + QString::fromLatin1(".error");
+               + QLatin1String(".error");
     }
 
     QDebug stream(QtMsgType type)
@@ -157,7 +155,7 @@ void akInit(const QString &appName)
     AkonadiCrash::init();
     sInstance()->setName(appName);
 
-    QFileInfo infoOld(sInstance()->errorLogFileName() + QString::fromLatin1(".old"));
+    QFileInfo infoOld(sInstance()->errorLogFileName() + QLatin1String(".old"));
     if (infoOld.exists()) {
         QFile fileOld(infoOld.absoluteFilePath());
         const bool success = fileOld.remove();
@@ -168,7 +166,7 @@ void akInit(const QString &appName)
     QFileInfo info(sInstance()->errorLogFileName());
     if (info.exists()) {
         QFile file(info.absoluteFilePath());
-        const bool success = file.rename(sInstance()->errorLogFileName() + QString::fromLatin1(".old"));
+        const bool success = file.rename(sInstance()->errorLogFileName() + QLatin1String(".old"));
         if (!success) {
             qFatal("Cannot rename log file - running on a readonly filesystem maybe?");
         }
